- codenames
- werewolf
- diplomacy
- negotiation
- poker
- bluffing dice [Done]


- Letter Auction: Players "bid" on letters to form the highest-scoring word. Each player has a limited number of points to bid with, and the goal is to assemble the highest-value word from the letters won.